/******************************************************************************/
/*  (C) COPYRIGHT International Business Machines Corp. 1993                  */
/*                            All Rights Reserved                             */
/*                                                                            */
/*  INTERNATIONAL BUSINESS MACHINES CORPORATION PROVIDES THIS MATERIAL        */
/*  "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED,        */
/*  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY  */
/*  AND FITNESS FOR A PARTICULAR PURPOSE.                                     */
/*                                                                            */
/******************************************************************************/
#include <X11/PEX5/PEXlib.h>
#include <X11/PEX5/PEXExtlib.h>
#include <X11/extensions/multibuf.h>
#include <misc.h>

static Multibuffer buffers[2], cur_buf;
extern int         create_mbx_buffers();

/****************************************************************************
 *  Sample actual test. Draws a polyine.                                    *
 ***************************************************************************/
void draw_model(Display          *dpy,
               XID              resourceID,
               PEXOCRequestType req_type)

{
    PEXCoord    pts1[2], pts2[2];
    PEXColor    line_color;
    PEXStructure test_struc;

    pts1[0].x = 0.0;
    pts1[0].y = 0.0;
    pts1[0].z = 0.0;

    pts1[1].x = 1.0;
    pts1[1].y = 1.0;
    pts1[1].z = 0.0;

    pts2[0].x = 1.0;
    pts2[0].y = 0.0;
    pts2[0].z = 0.0;

    pts2[1].x = 0.0;
    pts2[1].y = 1.0;
    pts2[1].z = 0.0;


    test_struc = PEXCreateStructure(dpy);
    line_color.rgb.red = 0.0;
    line_color.rgb.green = 0.0;
    line_color.rgb.blue = 1.0;
  
    PEXSetLineColor(dpy, test_struc, PEXOCStore, PEXColorTypeRGB, &line_color);
    PEXPolyline(dpy, test_struc, PEXOCStore, 2, pts1);
    line_color.rgb.green = 1.0;
    PEXSetLineColor(dpy, test_struc, PEXOCStore, PEXColorTypeRGB, &line_color);
    PEXPolyline(dpy, test_struc, PEXOCStore, 2, pts2);
 
    PEXRenderNetwork(dpy, cur_buf, resourceID, test_struc); 

    /* Display the buffer. */
    XmbufDisplayBuffers( dpy, 1, &cur_buf, 0, 0 );
    XFlush( dpy );
    
    /* Make the undisplayed buffer the drawing buffer. */
    cur_buf = (cur_buf == buffers[0] ? buffers[1] : buffers[0]);
}

/****************************************************************************
 *  Sets the test parameters                                                *
 ***************************************************************************/
void inquire_test_params(char *test_name,
                         int  *num_images,
                         int  *supported_modes,
                         char *win_title)

{
    strcpy(test_name, "mbx");
    *num_images = 1;
    *supported_modes = IMM_MODE | STR_MODE;

    strcpy(win_title, "IBM MBX test");
}


/****************************************************************************
 *  This routine is used to do miscellaneous things like setting some       *
 *  renderer attributess, Viewing etc if needed.                            *
 ***************************************************************************/
void misc_setup(Display *dpy, Window window, PEXRenderer renderer,
                int cur_image)
{
    /* Create the MBX buffers. */
    if ( create_mbx_buffers( dpy, window, 2, buffers ) )
	/* Set the current buffer to buffer 1. */
	cur_buf = buffers[1];
    else	
	exit( 1 );
}

/****************************************************************************
 *  This routine calls the function which does the actual test              *
 ***************************************************************************/
void execute_test(Display *dpy, XID resourceID,
               PEXOCRequestType req_type, int cur_image)
  {

    describe_test( "\n" );
    describe_test( " IBM Multi Buffering Extension Test:\n");
    describe_test( "\n" );
    describe_test( " This test will attempt to use the multibuffering extension.\n");
    describe_test( " It will draw some polylines to the back buffer and then \n");
    describe_test( " perform a swap so that the polylines can be seen.\n"); 
    describe_test( "\n"); 

    draw_model(dpy, resourceID, req_type);

  }

void testproc(Display *dpy, Window window, int cur_image)
  {
    image_testproc("mbx", "IBM MBX test", img_desc,
                    dpy,window, 0, 0,
                    glob_window_width, glob_window_height);
  }

int create_mbx_buffers( dpy, window, num_buffers, buffers )
    Display	*dpy;
    Window	window;
    int		num_buffers;
    Multibuffer	*buffers;
{
    int		first_event, first_error, num;
    
    if ( !XmbufQueryExtension( dpy, &first_event, &first_error ) ) {
        fprintf( stderr, "No multi-buffer extension on %s\n",
		 XDisplayString( dpy ) );
	return 0;
    }

    num = XmbufCreateBuffers( dpy, window, num_buffers,
			      MultibufferUpdateActionBackground,
			      MultibufferUpdateHintFrequent,
			      buffers );
    if ( num != num_buffers ) {
        fprintf( stderr, "Can't create %d buffers\n", num_buffers );
	if ( num > 0 )
	    XmbufDestroyBuffers( dpy, window );
	return 0;
    }

    return num;
}
