/*
******************************************************************************
** PEXlib Texture Mapping Test Code 
**
** $Source: /src/rcs/Cats/XSystem/pex/txm_utility_code/translate_string.c,v $
** $Revision: 510.1 $
** $Date: 94/02/26 10:42:26 $
** $Author: hmgr $
******************************************************************************
*/

/*
 * TRANSLATE_STRING.C -- This module builds a table to convert constant strings
 *                       to their correct values.  It outputs a file defined
 *                       by the constant OUTPUT_FILE.  This file is read by 
 *                       convert_strings.c during testing.
 *
 *             Designed by Bradley L. Saunders     Dec. 20, 1993
 */

/******************************************************************************/
/*                                                                            */
/*  (c) Copyright Hewlett-Packard Company, 1993, Fort Collins, Colorado       */
/*                                                                            */
/*                            All Rights Reserved                             */
/*                                                                            */
/*  Permission to use, copy, modify, and distribute this software and its     */
/*  documentation for any purpose and without fee is hereby granted,          */
/*  provided that the above copyright notices appear in all copies and that   */
/*  both the copyright notices and this permission notice appear in           */
/*  supporting documentation, and that the name of Hewlett-Packard not be     */
/*  used in advertising or publicity pertaining to distribution of the        */
/*  software without specific, written prior permission.                      */
/*                                                                            */
/*  HEWLETT-PACKARD MAKES NO WARRANTY OF ANY KIND WITH REGARD TO THIS         */
/*  SOFTWARE, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF        */
/*  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  Hewlett-Packard    */
/*  shall not be liable for errors contained herein or direct, indirect,      */
/*  special, incidental or consequential damages in connection with the       */
/*  furnishing, performance or use of this software.                          */
/*                                                                            */
/******************************************************************************/

#include <stdio.h>
#include <X11/PEX5/PEX.h>
#include <X11/PEX5/PEXlib.h>
#include <X11/PEX5/PEXExt.h>

#define OUTPUT_FILE "./string_table"

void main()
/*
 ******************************************************************************
 **    Description:
 **       This module builds a table to convert constant strings
 **       to their correct values.  It outputs a file defined
 **       by the constant OUTPUT_FILE.  This file is read by 
 **       convert_strings.c during testing.
 **
 **    Author:
 **       Brad Saunders                Dec. 20, 1993
 **
 **    Input parameters:
 **       None.
 **
 **    Output parameters:
 **       None.
 **
 **    Entry Conditions:
 **       None.
 **
 **    Exit Conditions:
 **       None.
 **
 **    Error Conditions:
 **       None.
 **
 **    Referenced by:
 **       None.
 **
 **    Procedure/Function dependencies:
 **       None.
 **
 ******************************************************************************
 */
{
  FILE *fout;

  fout = fopen(OUTPUT_FILE,"w");
  if(fout == NULL)
  {
    fprintf(stderr, "Could not open output file- '%s' \n",OUTPUT_FILE);
    exit(1);
  }

  fprintf(fout, "PEXInteriorStyleHollow\t%d\n",PEXInteriorStyleHollow);
  fprintf(fout, "PEXInteriorStyleSolid\t%d\n",PEXInteriorStyleSolid);
  fprintf(fout, "PEXInteriorStylePattern\t%d\n",PEXInteriorStylePattern);
  fprintf(fout, "PEXInteriorStyleHatch\t%d\n",PEXInteriorStyleHatch);
  fprintf(fout, "PEXInteriorStyleEmpty\t%d\n",PEXInteriorStyleEmpty);
  fprintf(fout, "PEXExtInteriorStyleTexture\t%d\n",PEXExtInteriorStyleTexture);

  fprintf(fout, "PEXColorTypeIndexed\t%d\n",PEXColorTypeIndexed);
  fprintf(fout, "PEXColorTypeRGB\t%d\n",PEXColorTypeRGB);
  fprintf(fout, "PEXColorTypeCIE\t%d\n",PEXColorTypeCIE);
  fprintf(fout, "PEXColorTypeHSV\t%d\n",PEXColorTypeHSV);
  fprintf(fout, "PEXColorTypeHLS\t%d\n",PEXColorTypeHLS);
  fprintf(fout, "PEXColorTypeRGB8\t%d\n",PEXColorTypeRGB8);
  fprintf(fout, "PEXColorTypeRGB16\t%d\n",PEXColorTypeRGB16);

  fprintf(fout, "PEXShapeComplex\t%d\n",PEXShapeComplex);
  fprintf(fout, "PEXShapeNonConvex\t%d\n",PEXShapeNonConvex);
  fprintf(fout, "PEXShapeConvex\t%d\n",PEXShapeConvex);
  fprintf(fout, "PEXShapeUnknown\t%d\n",PEXShapeUnknown);

  fprintf(fout, "PEXContourDisjoint\t%d\n",PEXContourDisjoint);
  fprintf(fout, "PEXContourNested\t%d\n",PEXContourNested);
  fprintf(fout, "PEXContourIntersecting\t%d\n",PEXContourIntersecting);
  fprintf(fout, "PEXContourUnknown\t%d\n",PEXContourUnknown);

  fprintf(fout, "PEXGANone\t%d\n",PEXGANone);
  fprintf(fout, "PEXGAColor\t%d\n",PEXGAColor);
  fprintf(fout, "PEXGANormal\t%d\n",PEXGANormal);
  fprintf(fout, "PEXGAEdges\t%d\n",PEXGAEdges);
  fprintf(fout, "PEXExtGAData\t%d\n",PEXExtGAData);
  fprintf(fout, "PEXOff\t%d\n",PEXOff);
  fprintf(fout, "PEXOn\t%d\n",PEXOn);

  fprintf(fout, "PEXClipXY\t%d\n",PEXClipXY);
  fprintf(fout, "PEXClipBack\t%d\n",PEXClipBack);
  fprintf(fout, "PEXClipFront\t%d\n",PEXClipFront);
  fprintf(fout, "PEXClippingAll\t%d\n",PEXClippingAll);
  fprintf(fout, "PEXClip\t%d\n",PEXClip);
  fprintf(fout, "PEXNoClip\t%d\n",PEXNoClip);

  fprintf(fout, "PEXNone\t%d\n",PEXNone);
  fprintf(fout, "PEXBackFaces\t%d\n",PEXBackFaces);
  fprintf(fout, "PEXFrontFaces\t%d\n",PEXFrontFaces);

  fprintf(fout, "PEXExtTMRenderingOrderPreSpecular\t%d\n",
    PEXExtTMRenderingOrderPreSpecular);
  fprintf(fout, "PEXExtTMRenderingOrderPostSpecular\t%d\n",
    PEXExtTMRenderingOrderPostSpecular);

  fprintf(fout, "PEXExtTMCoordSourceVertexCoord\t%d\n",
    PEXExtTMCoordSourceVertexCoord);
  fprintf(fout, "PEXExtTMCoordSourceVertexNormal\t%d\n",
    PEXExtTMCoordSourceVertexNormal);
  fprintf(fout, "PEXExtTMCoordSourceFloatData\t%d\n",
    PEXExtTMCoordSourceFloatData);

  fprintf(fout, "PEXReflectionNone\t%d\n",PEXReflectionNone);
  fprintf(fout, "PEXReflectionAmbient\t%d\n",PEXReflectionAmbient);
  fprintf(fout, "PEXReflectionDiffuse\t%d\n",PEXReflectionDiffuse);
  fprintf(fout, "PEXReflectionSpecular\t%d\n",PEXReflectionSpecular);

  fprintf(fout, "PEXExtTMCompositeReplace\t%d\n",PEXExtTMCompositeReplace);
  fprintf(fout, "PEXExtTMCompositeModulate\t%d\n",PEXExtTMCompositeModulate);
  fprintf(fout, "PEXExtTMCompositeBlendEnvColor\t%d\n",
    PEXExtTMCompositeBlendEnvColor);
  fprintf(fout, "PEXExtTMCompositeDecal\t%d\n",PEXExtTMCompositeDecal);
  fprintf(fout, "PEXExtTMCompositeDecalBackground\t%d\n",
    PEXExtTMCompositeDecalBackground);
  fprintf(fout, "PEXExtTMCompositeReplaceBlendedColors\t%d\n",
    PEXExtTMCompositeReplaceBlendedColors);

  fprintf(fout, "PEXExtTMTexelSampleSingleBase\t%d\n",
    PEXExtTMTexelSampleSingleBase);
  fprintf(fout, "PEXExtTMTexelSampleLinearBase\t%d\n",
    PEXExtTMTexelSampleLinearBase);
  fprintf(fout, "PEXExtTMTexelSampleSingleInMipmap\t%d\n",
    PEXExtTMTexelSampleSingleInMipmap);
  fprintf(fout, "PEXExtTMTexelSampleLinearInMipmap\t%d\n",
    PEXExtTMTexelSampleLinearInMipmap);
  fprintf(fout, "PEXExtTMTexelSampleSingleBetweenMipmaps\t%d\n",
    PEXExtTMTexelSampleSingleBetweenMipmaps);
  fprintf(fout, "PEXExtTMTexelSampleLinearBetweenMipmaps\t%d\n",
    PEXExtTMTexelSampleLinearBetweenMipmaps);

  fprintf(fout, "PEXExtTMBoundaryCondClampColor\t%d\n",
    PEXExtTMBoundaryCondClampColor);
/* BLS */
  fprintf(fout, "PEXExtTMClampColorSourceAbsolute\t%d\n",
    PEXExtTMClampColorSourceAbsolute);
  fprintf(fout, "PEXExtTMBoundaryCondBoundary\t%d\n",
    PEXExtTMBoundaryCondBoundary);
/* end BLS */
  fprintf(fout, "PEXExtTMBoundaryCondWrap\t%d\n",
    PEXExtTMBoundaryCondWrap);
  fprintf(fout, "PEXExtTMBoundaryCondMirror\t%d\n",
    PEXExtTMBoundaryCondMirror);

  fprintf(fout, "PEXExtTMClampColorSourceExplicit\t%d\n",
    PEXExtTMClampColorSourceExplicit);

  fprintf(fout, "PEXExtTMDomainColor1D\t%d\n",PEXExtTMDomainColor1D);
  fprintf(fout, "PEXExtTMDomainColor2D\t%d\n",PEXExtTMDomainColor2D);
  fprintf(fout, "PEXExtTMDomainColor3D\t%d\n",PEXExtTMDomainColor3D);

  fprintf(fout, "PEXExtTexelLuminanceFloat\t%d\n",PEXExtTexelLuminanceFloat);
  fprintf(fout, "PEXExtTexelLuminanceInt8\t%d\n",PEXExtTexelLuminanceInt8);
  fprintf(fout, "PEXExtTexelLuminanceInt16\t%d\n",PEXExtTexelLuminanceInt16);
  fprintf(fout, "PEXExtTexelLuminanceAlphaFloat\t%d\n",
    PEXExtTexelLuminanceAlphaFloat);
  fprintf(fout, "PEXExtTexelLuminanceAlphaInt8\t%d\n",
    PEXExtTexelLuminanceAlphaInt8);
  fprintf(fout, "PEXExtTexelLuminanceAlphaInt16\t%d\n",
    PEXExtTexelLuminanceAlphaInt16);
  fprintf(fout, "PEXExtTexelRGBInt8\t%d\n",PEXExtTexelRGBInt8);
  fprintf(fout, "PEXExtTexelRGBInt16\t%d\n",PEXExtTexelRGBInt16);
  fprintf(fout, "PEXExtTexelRGBAlphaFloat\t%d\n",PEXExtTexelRGBAlphaFloat);
  fprintf(fout, "PEXExtTexelRGBAlphaInt8\t%d\n",PEXExtTexelRGBAlphaInt8);
  fprintf(fout, "PEXExtTexelRGBAlphaInt16\t%d\n",PEXExtTexelRGBAlphaInt16);

  fprintf(fout, "PEXExtTMTypeMipMap\t%d\n",PEXExtTMTypeMipMap);

  fprintf(fout, "PEXExtTMParamExplicit\t%d\n",PEXExtTMParamExplicit);
  fprintf(fout, "PEXExtTMParamReflectSphereVRC\t%d\n",
    PEXExtTMParamReflectSphereVRC);
  fprintf(fout, "PEXExtTMParamReflectSphereWC\t%d\n",
    PEXExtTMParamReflectSphereWC);
  fprintf(fout, "PEXExtTMParamLinearVRC\t%d\n",PEXExtTMParamLinearVRC);

  fprintf(fout, "PEXExtTMPerspCorrectNone\t%d\n",PEXExtTMPerspCorrectNone);
  fprintf(fout, "PEXExtTMPerspCorrectVertex\t%d\n",PEXExtTMPerspCorrectVertex);
  fprintf(fout, "PEXExtTMPerspCorrectPixel\t%d\n",PEXExtTMPerspCorrectPixel);

  fprintf(fout, "PEXExtTMSampleFrequencyPixel\t%d\n",
    PEXExtTMSampleFrequencyPixel);
  fprintf(fout, "PEXExtTMSampleFrequencyInterpDep\t%d\n",
    PEXExtTMSampleFrequencyInterpDep);

  fprintf(fout, "PEXExtTMResourceHintNone\t%d\n",PEXExtTMResourceHintNone);
  fprintf(fout, "PEXExtTMResourceHintSpeed\t%d\n",PEXExtTMResourceHintSpeed);
  fprintf(fout, "PEXExtTMResourceHintSpace\t%d\n",PEXExtTMResourceHintSpace);

  fprintf(fout, "PEXExtChannelRed\t%d\n",PEXExtChannelRed);
  fprintf(fout, "PEXExtChannelGreen\t%d\n",PEXExtChannelGreen);
  fprintf(fout, "PEXExtChannelBlue\t%d\n",PEXExtChannelBlue);
  fprintf(fout, "PEXExtChannelAlpha\t%d\n",PEXExtChannelAlpha);
  fprintf(fout, "PEXExtChannelNTSCLuminance\t%d\n",PEXExtChannelNTSCLuminance);

  fprintf(fout, "PEXExtTMProjectionSphereWC\t%d\n",PEXExtTMProjectionSphereWC);
  fprintf(fout, "PEXExtTMProjectionCylinderWC\t%d\n",
    PEXExtTMProjectionCylinderWC);
  fprintf(fout, "PEXExtTMProjectionLinearWC\t%d\n",PEXExtTMProjectionLinearWC);

  fclose(fout);
}
